#!/bin/bash
#
# Makefile installation helper

if [ "$1" == "" ]; then ACTION="-i";else ACTION=$1;fi
if [ "$2" == "" ]; then CONFDIR="/etc";else CONFDIR=$2;fi
if [ "$3" == "" ]; then BINDIR="/usr/sbin";else BINDIR=$3;fi

#Find out where auditd.conf resides
if [ -f $CONFDIR/audit/auditd.conf ]; then
	AUDITCONF="audit/auditd.conf"
	AUDITRULES="audit/audit.rules"
else
	AUDITCONF="auditd.conf"
	AUDITRULES="audit.rules"
fi

if [ "$ACTION" == "-i" ]; then
	# Install
	VERSION=`/sbin/auditctl -v | /usr/bin/awk '{print $3}'`
	MAJOR=`echo $VERSION | cut -d. -f1`
	MINOR=`echo $VERSION | cut -d. -f2`
	RELEASE=`echo $VERSION | cut -d. -f3`

	VERSIONOK=0
	if [ $MAJOR -gt 1 ]; then
		VERSIONOK=1
	elif [ $MAJOR -eq 1 ]; then
		if [ $MINOR -gt 0 ]; then
			VERSIONOK=1
		elif [ $MINOR -eq 0 ]; then
			if [ $RELEASE -ge 15 ]; then
				VERSIONOK=1
			fi
		fi
	fi

	if [ $VERSIONOK -ne 1 ]; then
		echo "Version 1.0.15 of the native audit daemon is required in order"
		echo "for snare to operate correctly. Please install this version"
		echo "or later."
		exit
	fi

	if [ -f $CONFDIR/init.d/auditd ]; then
			$CONFDIR/init.d/auditd stop
		else
			systemctl stop auditd.service
	fi

	if [ ! -f $CONFDIR/$AUDITCONF-snarebackup ]; then
        	cp $CONFDIR/$AUDITCONF $CONFDIR/$AUDITCONF-snarebackup
	fi
	if [ ! -f $CONFDIR/$AUDITRULES-snarebackup ]; then
        	cp $CONFDIR/$AUDITRULES $CONFDIR/$AUDITRULES-snarebackup
	fi
 
	if [ -f /usr/sbin/semodule ] && [ -f snare.pp ]; then
		/usr/sbin/semodule -i snare.pp
	fi


	cp SnareDispatcher.pl $BINDIR/SnareDispatcher
	cp SnareDispatchHelper $BINDIR/SnareDispatchHelper
	chmod 750 $BINDIR/SnareDispatchHelper
	cp SnareWebServer.pl $BINDIR/SnareWebServer.pl
	cp SnareTranslationTable $BINDIR/SnareTranslationTable
	# If the snare.conf exists, DO NOT copy it across
	if [ ! -f $CONFDIR/snare.conf ]; then 
		cp snare.conf $CONFDIR 
	fi
	chmod 700 $CONFDIR/snare.conf
	$BINDIR/SnareTranslationTable
	

	echo "# SnareDispatchHelper added" > $CONFDIR/$AUDITCONF
	cat $CONFDIR/$AUDITCONF-snarebackup | sed 's/^dispatcher.*//' | sed 's/^log_format =.*/log_format = NOLOG/' | egrep -v "^$" >> $CONFDIR/$AUDITCONF
	echo "dispatcher = $BINDIR/SnareDispatchHelper" >> $CONFDIR/$AUDITCONF
	cat $CONFDIR/$AUDITRULES-snarebackup | sed 's/^-D.*//' | egrep -v "^$" > $CONFDIR/$AUDITRULES

	if [ -f $CONFDIR/init.d/auditd ]; then
		$CONFDIR/init.d/auditd start
	else
		systemctl start auditd.service
	fi

	exit
fi

if [ $1 == "-u" ]; then
	# Uninstall
	UNINST=`rpm -q SnareLinux | wc -l`
	if [ $UNINST -le 1 ]; then
		if [ -f $CONFDIR/init.d/auditd ]; then
			$CONFDIR/init.d/auditd stop
		else
			systemctl stop auditd.service
		fi

		if [ -f $CONFDIR/$AUDITCONF-snarebackup ]; then
			cat $CONFDIR/$AUDITCONF-snarebackup | sed 's/^log_format =.*/log_format = RAW/' | egrep -v "^dispatcher = .*SnareDispatch.*" > $CONFDIR/$AUDITCONF
			rm -f $CONFDIR/$AUDITCONF-snarebackup
		else
			cp $CONFDIR/$AUDITCONF $CONFDIR/$AUDITCONF-snarebackup
			cat $CONFDIR/$AUDITCONF-snarebackup | sed 's/^log_format =.*/log_format = RAW/' | egrep -v "^dispatcher" > $CONFDIR/$AUDITCONF
			rm -f $CONFDIR/$AUDITCONF-snarebackup
		fi

		if [ -f /usr/sbin/semodule ]; then
			/usr/sbin/semodule -l | egrep "^snare" > /dev/null
			if [ "$?" -eq 0 ]; then
				/usr/sbin/semodule -r snare;
			fi
		fi

		# Remove ALL the files
		if [ -f $CONFDIR/snare.conf ]; then rm -f $CONFDIR/snare.conf;fi
		if [ -f $BINDIR/SnareDispatcher ]; then rm -f $BINDIR/SnareDispatcher;fi
		if [ -f $BINDIR/SnareDispatchHelper ]; then rm -f $BINDIR/SnareDispatchHelper;fi
		if [ -f $BINDIR/SnareWebServer.pl ]; then rm -f $BINDIR/SnareWebServer.pl;fi
		if [ -f $BINDIR/SnareTranslationTable ]; then rm -f $BINDIR/SnareTranslationTable;fi
		if [ -f $CONFDIR/snare-xlate.conf ]; then rm -f $CONFDIR/snare-xlate.conf; fi
		if [ -f $CONFDIR/snare-xlate32.conf ]; then rm -f $CONFDIR/snare-xlate32.conf; fi

		if [ -f $CONFDIR/init.d/auditd ]; then
			$CONFDIR/init.d/auditd start
		else
			systemctl start auditd.service
		fi
	fi
	exit
fi
